Crate err_report

Crate err_report 

Clone of the unstable std::error::Report type.

Backtrace support is omitted due to nightly requirement.

Copied on 2025-09-09.

Structs

Report
An error reporter that prints an error and its sources.

Traits

Error
Error is a trait representing the basic expectations for error values, i.e., values of type E in Result<T, E>.